# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'manuskript/ui/settings_ui.ui'
#
# Created by: PyQt5 UI code generator 5.13.0
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Settings(object):
    def setupUi(self, Settings):
        Settings.setObjectName("Settings")
        Settings.resize(658, 598)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout(Settings)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.lstMenu = QtWidgets.QListWidget(Settings)
        self.lstMenu.setWordWrap(True)
        self.lstMenu.setObjectName("lstMenu")
        item = QtWidgets.QListWidgetItem()
        self.lstMenu.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.lstMenu.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.lstMenu.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.lstMenu.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.lstMenu.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.lstMenu.addItem(item)
        self.horizontalLayout_8.addWidget(self.lstMenu)
        self.stack = QtWidgets.QStackedWidget(Settings)
        self.stack.setObjectName("stack")
        self.stackedWidgetPage1 = QtWidgets.QWidget()
        self.stackedWidgetPage1.setObjectName("stackedWidgetPage1")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.stackedWidgetPage1)
        self.verticalLayout_7.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.lblTitleGeneral = QtWidgets.QLabel(self.stackedWidgetPage1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lblTitleGeneral.sizePolicy().hasHeightForWidth())
        self.lblTitleGeneral.setSizePolicy(sizePolicy)
        self.lblTitleGeneral.setAlignment(QtCore.Qt.AlignCenter)
        self.lblTitleGeneral.setObjectName("lblTitleGeneral")
        self.verticalLayout_7.addWidget(self.lblTitleGeneral)
        self.groupBox_2 = QtWidgets.QGroupBox(self.stackedWidgetPage1)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.groupBox_2.setFont(font)
        self.groupBox_2.setObjectName("groupBox_2")
        self.formLayout_13 = QtWidgets.QFormLayout(self.groupBox_2)
        self.formLayout_13.setFieldGrowthPolicy(QtWidgets.QFormLayout.FieldsStayAtSizeHint)
        self.formLayout_13.setObjectName("formLayout_13")
        self.label_56 = QtWidgets.QLabel(self.groupBox_2)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_56.setFont(font)
        self.label_56.setObjectName("label_56")
        self.formLayout_13.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_56)
        self.cmbStyle = QtWidgets.QComboBox(self.groupBox_2)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.cmbStyle.setFont(font)
        self.cmbStyle.setObjectName("cmbStyle")
        self.formLayout_13.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.cmbStyle)
        self.label_57 = QtWidgets.QLabel(self.groupBox_2)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_57.setFont(font)
        self.label_57.setObjectName("label_57")
        self.formLayout_13.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.label_57)
        self.cmbTranslation = QtWidgets.QComboBox(self.groupBox_2)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.cmbTranslation.setFont(font)
        self.cmbTranslation.setObjectName("cmbTranslation")
        self.formLayout_13.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.cmbTranslation)
        self.label_58 = QtWidgets.QLabel(self.groupBox_2)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_58.setFont(font)
        self.label_58.setObjectName("label_58")
        self.formLayout_13.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.label_58)
        self.spnGeneralFontSize = QtWidgets.QSpinBox(self.groupBox_2)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.spnGeneralFontSize.setFont(font)
        self.spnGeneralFontSize.setObjectName("spnGeneralFontSize")
        self.formLayout_13.setWidget(7, QtWidgets.QFormLayout.FieldRole, self.spnGeneralFontSize)
        self.label_2 = QtWidgets.QLabel(self.groupBox_2)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_2.setFont(font)
        self.label_2.setWordWrap(True)
        self.label_2.setObjectName("label_2")
        self.formLayout_13.setWidget(2, QtWidgets.QFormLayout.SpanningRole, self.label_2)
        self.verticalLayout_7.addWidget(self.groupBox_2)
        self.groupBox_10 = QtWidgets.QGroupBox(self.stackedWidgetPage1)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.groupBox_10.setFont(font)
        self.groupBox_10.setObjectName("groupBox_10")
        self.verticalLayout_18 = QtWidgets.QVBoxLayout(self.groupBox_10)
        self.verticalLayout_18.setObjectName("verticalLayout_18")
        self.chkAutoLoad = QtWidgets.QCheckBox(self.groupBox_10)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.chkAutoLoad.setFont(font)
        self.chkAutoLoad.setChecked(True)
        self.chkAutoLoad.setObjectName("chkAutoLoad")
        self.verticalLayout_18.addWidget(self.chkAutoLoad)
        self.verticalLayout_7.addWidget(self.groupBox_10)
        self.groupBox = QtWidgets.QGroupBox(self.stackedWidgetPage1)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.groupBox.setFont(font)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.chkAutoSave = QtWidgets.QCheckBox(self.groupBox)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.chkAutoSave.setFont(font)
        self.chkAutoSave.setChecked(True)
        self.chkAutoSave.setObjectName("chkAutoSave")
        self.horizontalLayout_5.addWidget(self.chkAutoSave)
        self.txtAutoSave = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtAutoSave.sizePolicy().hasHeightForWidth())
        self.txtAutoSave.setSizePolicy(sizePolicy)
        self.txtAutoSave.setMaximumSize(QtCore.QSize(50, 16777215))
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.txtAutoSave.setFont(font)
        self.txtAutoSave.setStyleSheet("border-radius: 6px;")
        self.txtAutoSave.setMaxLength(3)
        self.txtAutoSave.setAlignment(QtCore.Qt.AlignCenter)
        self.txtAutoSave.setObjectName("txtAutoSave")
        self.horizontalLayout_5.addWidget(self.txtAutoSave)
        self.label = QtWidgets.QLabel(self.groupBox)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.horizontalLayout_5.addWidget(self.label)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem)
        self.verticalLayout_6.addLayout(self.horizontalLayout_5)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.chkAutoSaveNoChanges = QtWidgets.QCheckBox(self.groupBox)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.chkAutoSaveNoChanges.setFont(font)
        self.chkAutoSaveNoChanges.setChecked(True)
        self.chkAutoSaveNoChanges.setObjectName("chkAutoSaveNoChanges")
        self.horizontalLayout_7.addWidget(self.chkAutoSaveNoChanges)
        self.txtAutoSaveNoChanges = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtAutoSaveNoChanges.sizePolicy().hasHeightForWidth())
        self.txtAutoSaveNoChanges.setSizePolicy(sizePolicy)
        self.txtAutoSaveNoChanges.setMaximumSize(QtCore.QSize(50, 16777215))
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.txtAutoSaveNoChanges.setFont(font)
        self.txtAutoSaveNoChanges.setStyleSheet("border-radius: 6px;")
        self.txtAutoSaveNoChanges.setMaxLength(3)
        self.txtAutoSaveNoChanges.setAlignment(QtCore.Qt.AlignCenter)
        self.txtAutoSaveNoChanges.setObjectName("txtAutoSaveNoChanges")
        self.horizontalLayout_7.addWidget(self.txtAutoSaveNoChanges)
        self.label_14 = QtWidgets.QLabel(self.groupBox)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_14.setFont(font)
        self.label_14.setObjectName("label_14")
        self.horizontalLayout_7.addWidget(self.label_14)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_7.addItem(spacerItem1)
        self.verticalLayout_6.addLayout(self.horizontalLayout_7)
        self.chkSaveOnQuit = QtWidgets.QCheckBox(self.groupBox)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.chkSaveOnQuit.setFont(font)
        self.chkSaveOnQuit.setChecked(True)
        self.chkSaveOnQuit.setObjectName("chkSaveOnQuit")
        self.verticalLayout_6.addWidget(self.chkSaveOnQuit)
        self.chkSaveToZip = QtWidgets.QCheckBox(self.groupBox)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.chkSaveToZip.setFont(font)
        self.chkSaveToZip.setStatusTip("")
        self.chkSaveToZip.setChecked(True)
        self.chkSaveToZip.setObjectName("chkSaveToZip")
        self.verticalLayout_6.addWidget(self.chkSaveToZip)
        self.verticalLayout_7.addWidget(self.groupBox)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_7.addItem(spacerItem2)
        self.stack.addWidget(self.stackedWidgetPage1)
        self.page_3 = QtWidgets.QWidget()
        self.page_3.setObjectName("page_3")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.page_3)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.lblTitleGeneral_2 = QtWidgets.QLabel(self.page_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lblTitleGeneral_2.sizePolicy().hasHeightForWidth())
        self.lblTitleGeneral_2.setSizePolicy(sizePolicy)
        self.lblTitleGeneral_2.setAlignment(QtCore.Qt.AlignCenter)
        self.lblTitleGeneral_2.setObjectName("lblTitleGeneral_2")
        self.verticalLayout.addWidget(self.lblTitleGeneral_2)
        self.label_44 = QtWidgets.QLabel(self.page_3)
        self.label_44.setWordWrap(True)
        self.label_44.setObjectName("label_44")
        self.verticalLayout.addWidget(self.label_44)
        self.chkRevisionsKeep = QtWidgets.QCheckBox(self.page_3)
        self.chkRevisionsKeep.setChecked(True)
        self.chkRevisionsKeep.setObjectName("chkRevisionsKeep")
        self.verticalLayout.addWidget(self.chkRevisionsKeep)
        self.chkRevisionRemove = QtWidgets.QGroupBox(self.page_3)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.chkRevisionRemove.setFont(font)
        self.chkRevisionRemove.setCheckable(True)
        self.chkRevisionRemove.setObjectName("chkRevisionRemove")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.chkRevisionRemove)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label_46 = QtWidgets.QLabel(self.chkRevisionRemove)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_46.setFont(font)
        self.label_46.setObjectName("label_46")
        self.gridLayout_2.addWidget(self.label_46, 1, 0, 1, 2)
        self.label_45 = QtWidgets.QLabel(self.chkRevisionRemove)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_45.setFont(font)
        self.label_45.setWordWrap(True)
        self.label_45.setObjectName("label_45")
        self.gridLayout_2.addWidget(self.label_45, 0, 0, 1, 2)
        self.label_50 = QtWidgets.QLabel(self.chkRevisionRemove)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_50.setFont(font)
        self.label_50.setObjectName("label_50")
        self.gridLayout_2.addWidget(self.label_50, 5, 1, 1, 1)
        self.spnRevisions10Mn = QtWidgets.QSpinBox(self.chkRevisionRemove)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spnRevisions10Mn.sizePolicy().hasHeightForWidth())
        self.spnRevisions10Mn.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.spnRevisions10Mn.setFont(font)
        self.spnRevisions10Mn.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spnRevisions10Mn.setMinimum(1)
        self.spnRevisions10Mn.setMaximum(999)
        self.spnRevisions10Mn.setProperty("value", 1)
        self.spnRevisions10Mn.setObjectName("spnRevisions10Mn")
        self.gridLayout_2.addWidget(self.spnRevisions10Mn, 2, 0, 1, 1)
        self.label_47 = QtWidgets.QLabel(self.chkRevisionRemove)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_47.setFont(font)
        self.label_47.setObjectName("label_47")
        self.gridLayout_2.addWidget(self.label_47, 2, 1, 1, 1)
        self.label_49 = QtWidgets.QLabel(self.chkRevisionRemove)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_49.setFont(font)
        self.label_49.setObjectName("label_49")
        self.gridLayout_2.addWidget(self.label_49, 4, 1, 1, 1)
        self.label_48 = QtWidgets.QLabel(self.chkRevisionRemove)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_48.setFont(font)
        self.label_48.setObjectName("label_48")
        self.gridLayout_2.addWidget(self.label_48, 3, 1, 1, 1)
        self.spnRevisionsDay = QtWidgets.QSpinBox(self.chkRevisionRemove)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spnRevisionsDay.sizePolicy().hasHeightForWidth())
        self.spnRevisionsDay.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.spnRevisionsDay.setFont(font)
        self.spnRevisionsDay.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spnRevisionsDay.setMinimum(1)
        self.spnRevisionsDay.setMaximum(999)
        self.spnRevisionsDay.setProperty("value", 1)
        self.spnRevisionsDay.setObjectName("spnRevisionsDay")
        self.gridLayout_2.addWidget(self.spnRevisionsDay, 4, 0, 1, 1)
        self.spnRevisionsHour = QtWidgets.QSpinBox(self.chkRevisionRemove)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spnRevisionsHour.sizePolicy().hasHeightForWidth())
        self.spnRevisionsHour.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.spnRevisionsHour.setFont(font)
        self.spnRevisionsHour.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spnRevisionsHour.setMinimum(1)
        self.spnRevisionsHour.setMaximum(999)
        self.spnRevisionsHour.setProperty("value", 1)
        self.spnRevisionsHour.setObjectName("spnRevisionsHour")
        self.gridLayout_2.addWidget(self.spnRevisionsHour, 3, 0, 1, 1)
        self.spnRevisionsMonth = QtWidgets.QSpinBox(self.chkRevisionRemove)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spnRevisionsMonth.sizePolicy().hasHeightForWidth())
        self.spnRevisionsMonth.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.spnRevisionsMonth.setFont(font)
        self.spnRevisionsMonth.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spnRevisionsMonth.setMinimum(1)
        self.spnRevisionsMonth.setMaximum(999)
        self.spnRevisionsMonth.setProperty("value", 1)
        self.spnRevisionsMonth.setObjectName("spnRevisionsMonth")
        self.gridLayout_2.addWidget(self.spnRevisionsMonth, 5, 0, 1, 1)
        self.spnRevisionsEternity = QtWidgets.QSpinBox(self.chkRevisionRemove)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spnRevisionsEternity.sizePolicy().hasHeightForWidth())
        self.spnRevisionsEternity.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.spnRevisionsEternity.setFont(font)
        self.spnRevisionsEternity.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spnRevisionsEternity.setMinimum(1)
        self.spnRevisionsEternity.setMaximum(999)
        self.spnRevisionsEternity.setProperty("value", 1)
        self.spnRevisionsEternity.setObjectName("spnRevisionsEternity")
        self.gridLayout_2.addWidget(self.spnRevisionsEternity, 6, 0, 1, 1)
        self.label_51 = QtWidgets.QLabel(self.chkRevisionRemove)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_51.setFont(font)
        self.label_51.setObjectName("label_51")
        self.gridLayout_2.addWidget(self.label_51, 6, 1, 1, 1)
        self.verticalLayout.addWidget(self.chkRevisionRemove)
        spacerItem3 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem3)
        self.label_revisionDeprecation = QtWidgets.QLabel(self.page_3)
        self.label_revisionDeprecation.setWordWrap(True)
        self.label_revisionDeprecation.setOpenExternalLinks(True)
        self.label_revisionDeprecation.setObjectName("label_revisionDeprecation")
        self.verticalLayout.addWidget(self.label_revisionDeprecation)
        self.stack.addWidget(self.page_3)
        self.stackedWidgetPage2 = QtWidgets.QWidget()
        self.stackedWidgetPage2.setObjectName("stackedWidgetPage2")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.stackedWidgetPage2)
        self.verticalLayout_9.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.lblTitleViews = QtWidgets.QLabel(self.stackedWidgetPage2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lblTitleViews.sizePolicy().hasHeightForWidth())
        self.lblTitleViews.setSizePolicy(sizePolicy)
        self.lblTitleViews.setAlignment(QtCore.Qt.AlignCenter)
        self.lblTitleViews.setObjectName("lblTitleViews")
        self.verticalLayout_9.addWidget(self.lblTitleViews)
        self.tabViews = QtWidgets.QTabWidget(self.stackedWidgetPage2)
        self.tabViews.setObjectName("tabViews")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.verticalLayout_17 = QtWidgets.QVBoxLayout(self.tab)
        self.verticalLayout_17.setObjectName("verticalLayout_17")
        self.groupBox_3 = QtWidgets.QGroupBox(self.tab)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.groupBox_3.setFont(font)
        self.groupBox_3.setObjectName("groupBox_3")
        self.formLayout = QtWidgets.QFormLayout(self.groupBox_3)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.ExpandingFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.label_3 = QtWidgets.QLabel(self.groupBox_3)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_3.setFont(font)
        self.label_3.setObjectName("label_3")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_3)
        self.cmbTreeIcon = QtWidgets.QComboBox(self.groupBox_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cmbTreeIcon.sizePolicy().hasHeightForWidth())
        self.cmbTreeIcon.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.cmbTreeIcon.setFont(font)
        self.cmbTreeIcon.setObjectName("cmbTreeIcon")
        self.cmbTreeIcon.addItem("")
        self.cmbTreeIcon.addItem("")
        self.cmbTreeIcon.addItem("")
        self.cmbTreeIcon.addItem("")
        self.cmbTreeIcon.addItem("")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.cmbTreeIcon)
        self.label_4 = QtWidgets.QLabel(self.groupBox_3)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_4.setFont(font)
        self.label_4.setObjectName("label_4")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_4)
        self.cmbTreeText = QtWidgets.QComboBox(self.groupBox_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cmbTreeText.sizePolicy().hasHeightForWidth())
        self.cmbTreeText.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.cmbTreeText.setFont(font)
        self.cmbTreeText.setObjectName("cmbTreeText")
        self.cmbTreeText.addItem("")
        self.cmbTreeText.addItem("")
        self.cmbTreeText.addItem("")
        self.cmbTreeText.addItem("")
        self.cmbTreeText.addItem("")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.cmbTreeText)
        self.label_5 = QtWidgets.QLabel(self.groupBox_3)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_5.setFont(font)
        self.label_5.setObjectName("label_5")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_5)
        self.cmbTreeBackground = QtWidgets.QComboBox(self.groupBox_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cmbTreeBackground.sizePolicy().hasHeightForWidth())
        self.cmbTreeBackground.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.cmbTreeBackground.setFont(font)
        self.cmbTreeBackground.setObjectName("cmbTreeBackground")
        self.cmbTreeBackground.addItem("")
        self.cmbTreeBackground.addItem("")
        self.cmbTreeBackground.addItem("")
        self.cmbTreeBackground.addItem("")
        self.cmbTreeBackground.addItem("")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.cmbTreeBackground)
        self.verticalLayout_17.addWidget(self.groupBox_3)
        self.groupBox_16 = QtWidgets.QGroupBox(self.tab)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.groupBox_16.setFont(font)
        self.groupBox_16.setObjectName("groupBox_16")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout(self.groupBox_16)
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.lblTreeIconSize = QtWidgets.QLabel(self.groupBox_16)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.lblTreeIconSize.setFont(font)
        self.lblTreeIconSize.setObjectName("lblTreeIconSize")
        self.horizontalLayout_11.addWidget(self.lblTreeIconSize)
        self.sldTreeIconSize = QtWidgets.QSlider(self.groupBox_16)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.sldTreeIconSize.setFont(font)
        self.sldTreeIconSize.setMinimum(16)
        self.sldTreeIconSize.setMaximum(128)
        self.sldTreeIconSize.setOrientation(QtCore.Qt.Horizontal)
        self.sldTreeIconSize.setObjectName("sldTreeIconSize")
        self.horizontalLayout_11.addWidget(self.sldTreeIconSize)
        self.verticalLayout_17.addWidget(self.groupBox_16)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.groupBox_8 = QtWidgets.QGroupBox(self.tab)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.groupBox_8.setFont(font)
        self.groupBox_8.setObjectName("groupBox_8")
        self.verticalLayout_15 = QtWidgets.QVBoxLayout(self.groupBox_8)
        self.verticalLayout_15.setObjectName("verticalLayout_15")
        self.rdoTreeItemCount = QtWidgets.QRadioButton(self.groupBox_8)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.rdoTreeItemCount.setFont(font)
        self.rdoTreeItemCount.setObjectName("rdoTreeItemCount")
        self.verticalLayout_15.addWidget(self.rdoTreeItemCount)
        self.rdoTreeWC = QtWidgets.QRadioButton(self.groupBox_8)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.rdoTreeWC.setFont(font)
        self.rdoTreeWC.setObjectName("rdoTreeWC")
        self.verticalLayout_15.addWidget(self.rdoTreeWC)
        self.rdoTreeProgress = QtWidgets.QRadioButton(self.groupBox_8)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.rdoTreeProgress.setFont(font)
        self.rdoTreeProgress.setObjectName("rdoTreeProgress")
        self.verticalLayout_15.addWidget(self.rdoTreeProgress)
        self.rdoTreeSummary = QtWidgets.QRadioButton(self.groupBox_8)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.rdoTreeSummary.setFont(font)
        self.rdoTreeSummary.setObjectName("rdoTreeSummary")
        self.verticalLayout_15.addWidget(self.rdoTreeSummary)
        self.rdoTreeNothing = QtWidgets.QRadioButton(self.groupBox_8)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.rdoTreeNothing.setFont(font)
        self.rdoTreeNothing.setChecked(True)
        self.rdoTreeNothing.setObjectName("rdoTreeNothing")
        self.verticalLayout_15.addWidget(self.rdoTreeNothing)
        self.horizontalLayout_9.addWidget(self.groupBox_8)
        self.groupBox_9 = QtWidgets.QGroupBox(self.tab)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.groupBox_9.setFont(font)
        self.groupBox_9.setObjectName("groupBox_9")
        self.verticalLayout_16 = QtWidgets.QVBoxLayout(self.groupBox_9)
        self.verticalLayout_16.setObjectName("verticalLayout_16")
        self.rdoTreeTextWC = QtWidgets.QRadioButton(self.groupBox_9)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.rdoTreeTextWC.setFont(font)
        self.rdoTreeTextWC.setObjectName("rdoTreeTextWC")
        self.verticalLayout_16.addWidget(self.rdoTreeTextWC)
        self.rdoTreeTextProgress = QtWidgets.QRadioButton(self.groupBox_9)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.rdoTreeTextProgress.setFont(font)
        self.rdoTreeTextProgress.setObjectName("rdoTreeTextProgress")
        self.verticalLayout_16.addWidget(self.rdoTreeTextProgress)
        self.rdoTreeTextSummary = QtWidgets.QRadioButton(self.groupBox_9)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.rdoTreeTextSummary.setFont(font)
        self.rdoTreeTextSummary.setObjectName("rdoTreeTextSummary")
        self.verticalLayout_16.addWidget(self.rdoTreeTextSummary)
        self.rdoTreeTextNothing = QtWidgets.QRadioButton(self.groupBox_9)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.rdoTreeTextNothing.setFont(font)
        self.rdoTreeTextNothing.setObjectName("rdoTreeTextNothing")
        self.verticalLayout_16.addWidget(self.rdoTreeTextNothing)
        spacerItem4 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_16.addItem(spacerItem4)
        self.horizontalLayout_9.addWidget(self.groupBox_9)
        self.verticalLayout_17.addLayout(self.horizontalLayout_9)
        spacerItem5 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_17.addItem(spacerItem5)
        icon = QtGui.QIcon.fromTheme("view-list-tree")
        self.tabViews.addTab(self.tab, icon, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.tab_2)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.groupBox_4 = QtWidgets.QGroupBox(self.tab_2)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.groupBox_4.setFont(font)
        self.groupBox_4.setObjectName("groupBox_4")
        self.formLayout_3 = QtWidgets.QFormLayout(self.groupBox_4)
        self.formLayout_3.setFieldGrowthPolicy(QtWidgets.QFormLayout.ExpandingFieldsGrow)
        self.formLayout_3.setObjectName("formLayout_3")
        self.label_6 = QtWidgets.QLabel(self.groupBox_4)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_6.setFont(font)
        self.label_6.setObjectName("label_6")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_6)
        self.cmbOutlineIcon = QtWidgets.QComboBox(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cmbOutlineIcon.sizePolicy().hasHeightForWidth())
        self.cmbOutlineIcon.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.cmbOutlineIcon.setFont(font)
        self.cmbOutlineIcon.setObjectName("cmbOutlineIcon")
        self.cmbOutlineIcon.addItem("")
        self.cmbOutlineIcon.addItem("")
        self.cmbOutlineIcon.addItem("")
        self.cmbOutlineIcon.addItem("")
        self.cmbOutlineIcon.addItem("")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.cmbOutlineIcon)
        self.label_7 = QtWidgets.QLabel(self.groupBox_4)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_7.setFont(font)
        self.label_7.setObjectName("label_7")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_7)
        self.cmbOutlineText = QtWidgets.QComboBox(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cmbOutlineText.sizePolicy().hasHeightForWidth())
        self.cmbOutlineText.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.cmbOutlineText.setFont(font)
        self.cmbOutlineText.setObjectName("cmbOutlineText")
        self.cmbOutlineText.addItem("")
        self.cmbOutlineText.addItem("")
        self.cmbOutlineText.addItem("")
        self.cmbOutlineText.addItem("")
        self.cmbOutlineText.addItem("")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.cmbOutlineText)
        self.cmbOutlineBackground = QtWidgets.QComboBox(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cmbOutlineBackground.sizePolicy().hasHeightForWidth())
        self.cmbOutlineBackground.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.cmbOutlineBackground.setFont(font)
        self.cmbOutlineBackground.setObjectName("cmbOutlineBackground")
        self.cmbOutlineBackground.addItem("")
        self.cmbOutlineBackground.addItem("")
        self.cmbOutlineBackground.addItem("")
        self.cmbOutlineBackground.addItem("")
        self.cmbOutlineBackground.addItem("")
        self.formLayout_3.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.cmbOutlineBackground)
        self.label_8 = QtWidgets.QLabel(self.groupBox_4)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_8.setFont(font)
        self.label_8.setObjectName("label_8")
        self.formLayout_3.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_8)
        self.verticalLayout_11.addWidget(self.groupBox_4)
        self.groupBox_6 = QtWidgets.QGroupBox(self.tab_2)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.groupBox_6.setFont(font)
        self.groupBox_6.setObjectName("groupBox_6")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox_6)
        self.gridLayout.setObjectName("gridLayout")
        self.chkOutlineGoal = QtWidgets.QCheckBox(self.groupBox_6)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.chkOutlineGoal.setFont(font)
        self.chkOutlineGoal.setChecked(True)
        self.chkOutlineGoal.setObjectName("chkOutlineGoal")
        self.gridLayout.addWidget(self.chkOutlineGoal, 4, 2, 1, 1)
        self.chkOutlineWordCount = QtWidgets.QCheckBox(self.groupBox_6)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.chkOutlineWordCount.setFont(font)
        self.chkOutlineWordCount.setChecked(True)
        self.chkOutlineWordCount.setObjectName("chkOutlineWordCount")
        self.gridLayout.addWidget(self.chkOutlineWordCount, 4, 1, 1, 1)
        self.chkOutlinePercentage = QtWidgets.QCheckBox(self.groupBox_6)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.chkOutlinePercentage.setFont(font)
        self.chkOutlinePercentage.setChecked(True)
        self.chkOutlinePercentage.setObjectName("chkOutlinePercentage")
        self.gridLayout.addWidget(self.chkOutlinePercentage, 4, 3, 1, 1)
        self.chkOutlineCompile = QtWidgets.QCheckBox(self.groupBox_6)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.chkOutlineCompile.setFont(font)
        self.chkOutlineCompile.setChecked(True)
        self.chkOutlineCompile.setObjectName("chkOutlineCompile")
        self.gridLayout.addWidget(self.chkOutlineCompile, 4, 0, 1, 1)
        self.chkOutlineStatus = QtWidgets.QCheckBox(self.groupBox_6)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.chkOutlineStatus.setFont(font)
        self.chkOutlineStatus.setChecked(True)
        self.chkOutlineStatus.setObjectName("chkOutlineStatus")
        self.gridLayout.addWidget(self.chkOutlineStatus, 3, 3, 1, 1)
        self.chkOutlineLabel = QtWidgets.QCheckBox(self.groupBox_6)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.chkOutlineLabel.setFont(font)
        self.chkOutlineLabel.setChecked(True)
        self.chkOutlineLabel.setObjectName("chkOutlineLabel")
        self.gridLayout.addWidget(self.chkOutlineLabel, 3, 2, 1, 1)
        self.chkOutlinePOV = QtWidgets.QCheckBox(self.groupBox_6)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.chkOutlinePOV.setFont(font)
        self.chkOutlinePOV.setChecked(True)
        self.chkOutlinePOV.setObjectName("chkOutlinePOV")
        self.gridLayout.addWidget(self.chkOutlinePOV, 3, 1, 1, 1)
        self.chkOutlineTitle = QtWidgets.QCheckBox(self.groupBox_6)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.chkOutlineTitle.setFont(font)
        self.chkOutlineTitle.setChecked(True)
        self.chkOutlineTitle.setObjectName("chkOutlineTitle")
        self.gridLayout.addWidget(self.chkOutlineTitle, 3, 0, 1, 1)
        self.verticalLayout_11.addWidget(self.groupBox_6)
        spacerItem6 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_11.addItem(spacerItem6)
        icon = QtGui.QIcon.fromTheme("view-outline")
        self.tabViews.addTab(self.tab_2, icon, "")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.tab_3)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.groupBox_7 = QtWidgets.QGroupBox(self.tab_3)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.groupBox_7.setFont(font)
        self.groupBox_7.setObjectName("groupBox_7")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.groupBox_7)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.label_15 = QtWidgets.QLabel(self.groupBox_7)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_15.setFont(font)
        self.label_15.setObjectName("label_15")
        self.verticalLayout_8.addWidget(self.label_15)
        self.btnCorkColor = QtWidgets.QPushButton(self.groupBox_7)
        self.btnCorkColor.setMaximumSize(QtCore.QSize(16777215, 32))
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.btnCorkColor.setFont(font)
        self.btnCorkColor.setText("")
        self.btnCorkColor.setIconSize(QtCore.QSize(64, 64))
        self.btnCorkColor.setObjectName("btnCorkColor")
        self.verticalLayout_8.addWidget(self.btnCorkColor)
        self.label_16 = QtWidgets.QLabel(self.groupBox_7)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_16.setFont(font)
        self.label_16.setObjectName("label_16")
        self.verticalLayout_8.addWidget(self.label_16)
        self.cmbCorkImage = QtWidgets.QComboBox(self.groupBox_7)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.cmbCorkImage.setFont(font)
        self.cmbCorkImage.setObjectName("cmbCorkImage")
        self.verticalLayout_8.addWidget(self.cmbCorkImage)
        spacerItem7 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_8.addItem(spacerItem7)
        self.gridLayout_3.addWidget(self.groupBox_7, 1, 1, 1, 1)
        self.groupBox_11 = QtWidgets.QGroupBox(self.tab_3)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.groupBox_11.setFont(font)
        self.groupBox_11.setObjectName("groupBox_11")
        self.verticalLayout_19 = QtWidgets.QVBoxLayout(self.groupBox_11)
        self.verticalLayout_19.setObjectName("verticalLayout_19")
        self.rdoCorkOldStyle = QtWidgets.QRadioButton(self.groupBox_11)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.rdoCorkOldStyle.setFont(font)
        self.rdoCorkOldStyle.setObjectName("rdoCorkOldStyle")
        self.verticalLayout_19.addWidget(self.rdoCorkOldStyle)
        self.rdoCorkNewStyle = QtWidgets.QRadioButton(self.groupBox_11)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.rdoCorkNewStyle.setFont(font)
        self.rdoCorkNewStyle.setObjectName("rdoCorkNewStyle")
        self.verticalLayout_19.addWidget(self.rdoCorkNewStyle)
        self.gridLayout_3.addWidget(self.groupBox_11, 0, 1, 1, 1)
        self.groupBox_5 = QtWidgets.QGroupBox(self.tab_3)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.groupBox_5.setFont(font)
        self.groupBox_5.setObjectName("groupBox_5")
        self.formLayout_2 = QtWidgets.QFormLayout(self.groupBox_5)
        self.formLayout_2.setFieldGrowthPolicy(QtWidgets.QFormLayout.ExpandingFieldsGrow)
        self.formLayout_2.setObjectName("formLayout_2")
        self.label_9 = QtWidgets.QLabel(self.groupBox_5)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_9.setFont(font)
        self.label_9.setObjectName("label_9")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_9)
        self.cmbCorkIcon = QtWidgets.QComboBox(self.groupBox_5)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.cmbCorkIcon.setFont(font)
        self.cmbCorkIcon.setObjectName("cmbCorkIcon")
        self.cmbCorkIcon.addItem("")
        self.cmbCorkIcon.addItem("")
        self.cmbCorkIcon.addItem("")
        self.cmbCorkIcon.addItem("")
        self.cmbCorkIcon.addItem("")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.cmbCorkIcon)
        self.label_10 = QtWidgets.QLabel(self.groupBox_5)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_10.setFont(font)
        self.label_10.setObjectName("label_10")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_10)
        self.cmbCorkText = QtWidgets.QComboBox(self.groupBox_5)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.cmbCorkText.setFont(font)
        self.cmbCorkText.setObjectName("cmbCorkText")
        self.cmbCorkText.addItem("")
        self.cmbCorkText.addItem("")
        self.cmbCorkText.addItem("")
        self.cmbCorkText.addItem("")
        self.cmbCorkText.addItem("")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.cmbCorkText)
        self.label_11 = QtWidgets.QLabel(self.groupBox_5)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_11.setFont(font)
        self.label_11.setObjectName("label_11")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_11)
        self.cmbCorkBackground = QtWidgets.QComboBox(self.groupBox_5)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.cmbCorkBackground.setFont(font)
        self.cmbCorkBackground.setObjectName("cmbCorkBackground")
        self.cmbCorkBackground.addItem("")
        self.cmbCorkBackground.addItem("")
        self.cmbCorkBackground.addItem("")
        self.cmbCorkBackground.addItem("")
        self.cmbCorkBackground.addItem("")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.cmbCorkBackground)
        self.label_12 = QtWidgets.QLabel(self.groupBox_5)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_12.setFont(font)
        self.label_12.setObjectName("label_12")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_12)
        self.cmbCorkBorder = QtWidgets.QComboBox(self.groupBox_5)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.cmbCorkBorder.setFont(font)
        self.cmbCorkBorder.setObjectName("cmbCorkBorder")
        self.cmbCorkBorder.addItem("")
        self.cmbCorkBorder.addItem("")
        self.cmbCorkBorder.addItem("")
        self.cmbCorkBorder.addItem("")
        self.cmbCorkBorder.addItem("")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.cmbCorkBorder)
        self.label_13 = QtWidgets.QLabel(self.groupBox_5)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_13.setFont(font)
        self.label_13.setObjectName("label_13")
        self.formLayout_2.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.label_13)
        self.cmbCorkCorner = QtWidgets.QComboBox(self.groupBox_5)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.cmbCorkCorner.setFont(font)
        self.cmbCorkCorner.setObjectName("cmbCorkCorner")
        self.cmbCorkCorner.addItem("")
        self.cmbCorkCorner.addItem("")
        self.cmbCorkCorner.addItem("")
        self.cmbCorkCorner.addItem("")
        self.cmbCorkCorner.addItem("")
        self.formLayout_2.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.cmbCorkCorner)
        self.gridLayout_3.addWidget(self.groupBox_5, 0, 0, 2, 1)
        icon = QtGui.QIcon.fromTheme("view-cards")
        self.tabViews.addTab(self.tab_3, icon, "")
        self.tab_4 = QtWidgets.QWidget()
        self.tab_4.setObjectName("tab_4")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.tab_4)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.verticalLayout_21 = QtWidgets.QVBoxLayout()
        self.verticalLayout_21.setObjectName("verticalLayout_21")
        self.groupBox_17 = QtWidgets.QGroupBox(self.tab_4)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.groupBox_17.setFont(font)
        self.groupBox_17.setObjectName("groupBox_17")
        self.formLayout_12 = QtWidgets.QFormLayout(self.groupBox_17)
        self.formLayout_12.setObjectName("formLayout_12")
        self.label_43 = QtWidgets.QLabel(self.groupBox_17)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_43.setFont(font)
        self.label_43.setObjectName("label_43")
        self.formLayout_12.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_43)
        self.btnEditorBackgroundColor = QtWidgets.QPushButton(self.groupBox_17)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnEditorBackgroundColor.sizePolicy().hasHeightForWidth())
        self.btnEditorBackgroundColor.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.btnEditorBackgroundColor.setFont(font)
        self.btnEditorBackgroundColor.setText("")
        self.btnEditorBackgroundColor.setObjectName("btnEditorBackgroundColor")
        self.formLayout_12.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.btnEditorBackgroundColor)
        self.chkEditorBackgroundTransparent = QtWidgets.QCheckBox(self.groupBox_17)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.chkEditorBackgroundTransparent.setFont(font)
        self.chkEditorBackgroundTransparent.setObjectName("chkEditorBackgroundTransparent")
        self.formLayout_12.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.chkEditorBackgroundTransparent)
        self.label_37 = QtWidgets.QLabel(self.groupBox_17)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_37.setFont(font)
        self.label_37.setObjectName("label_37")
        self.formLayout_12.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_37)
        self.btnEditorFontColor = QtWidgets.QPushButton(self.groupBox_17)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnEditorFontColor.sizePolicy().hasHeightForWidth())
        self.btnEditorFontColor.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.btnEditorFontColor.setFont(font)
        self.btnEditorFontColor.setText("")
        self.btnEditorFontColor.setObjectName("btnEditorFontColor")
        self.formLayout_12.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.btnEditorFontColor)
        self.btnEditorColorDefault = QtWidgets.QPushButton(self.groupBox_17)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.btnEditorColorDefault.setFont(font)
        self.btnEditorColorDefault.setObjectName("btnEditorColorDefault")
        self.formLayout_12.setWidget(3, QtWidgets.QFormLayout.SpanningRole, self.btnEditorColorDefault)
        self.verticalLayout_21.addWidget(self.groupBox_17)
        self.groupBox_12 = QtWidgets.QGroupBox(self.tab_4)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.groupBox_12.setFont(font)
        self.groupBox_12.setObjectName("groupBox_12")
        self.formLayout_8 = QtWidgets.QFormLayout(self.groupBox_12)
        self.formLayout_8.setObjectName("formLayout_8")
        self.label_39 = QtWidgets.QLabel(self.groupBox_12)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_39.setFont(font)
        self.label_39.setObjectName("label_39")
        self.formLayout_8.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_39)
        self.cmbEditorFontFamily = QtWidgets.QFontComboBox(self.groupBox_12)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cmbEditorFontFamily.sizePolicy().hasHeightForWidth())
        self.cmbEditorFontFamily.setSizePolicy(sizePolicy)
        self.cmbEditorFontFamily.setMaximumSize(QtCore.QSize(150, 16777215))
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.cmbEditorFontFamily.setFont(font)
        self.cmbEditorFontFamily.setObjectName("cmbEditorFontFamily")
        self.formLayout_8.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.cmbEditorFontFamily)
        self.label_38 = QtWidgets.QLabel(self.groupBox_12)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_38.setFont(font)
        self.label_38.setObjectName("label_38")
        self.formLayout_8.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.label_38)
        self.label_36 = QtWidgets.QLabel(self.groupBox_12)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_36.setFont(font)
        self.label_36.setObjectName("label_36")
        self.formLayout_8.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.label_36)
        self.btnEditorMisspelledColor = QtWidgets.QPushButton(self.groupBox_12)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnEditorMisspelledColor.sizePolicy().hasHeightForWidth())
        self.btnEditorMisspelledColor.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.btnEditorMisspelledColor.setFont(font)
        self.btnEditorMisspelledColor.setText("")
        self.btnEditorMisspelledColor.setObjectName("btnEditorMisspelledColor")
        self.formLayout_8.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.btnEditorMisspelledColor)
        self.spnEditorFontSize = QtWidgets.QSpinBox(self.groupBox_12)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.spnEditorFontSize.setFont(font)
        self.spnEditorFontSize.setMinimum(4)
        self.spnEditorFontSize.setMaximum(299)
        self.spnEditorFontSize.setProperty("value", 10)
        self.spnEditorFontSize.setObjectName("spnEditorFontSize")
        self.formLayout_8.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.spnEditorFontSize)
        self.verticalLayout_21.addWidget(self.groupBox_12)
        self.groupBox_161 = QtWidgets.QGroupBox(self.tab_4)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.groupBox_161.setFont(font)
        self.groupBox_161.setObjectName("groupBox_161")
        self.formLayout_11 = QtWidgets.QFormLayout(self.groupBox_161)
        self.formLayout_11.setObjectName("formLayout_11")
        self.chkEditorMaxWidth = QtWidgets.QCheckBox(self.groupBox_161)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.chkEditorMaxWidth.setFont(font)
        self.chkEditorMaxWidth.setObjectName("chkEditorMaxWidth")
        self.formLayout_11.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.chkEditorMaxWidth)
        self.spnEditorMaxWidth = QtWidgets.QSpinBox(self.groupBox_161)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.spnEditorMaxWidth.setFont(font)
        self.spnEditorMaxWidth.setMaximum(4096)
        self.spnEditorMaxWidth.setProperty("value", 500)
        self.spnEditorMaxWidth.setObjectName("spnEditorMaxWidth")
        self.formLayout_11.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.spnEditorMaxWidth)
        self.label_54 = QtWidgets.QLabel(self.groupBox_161)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_54.setFont(font)
        self.label_54.setObjectName("label_54")
        self.formLayout_11.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_54)
        self.spnEditorMarginsLR = QtWidgets.QSpinBox(self.groupBox_161)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.spnEditorMarginsLR.setFont(font)
        self.spnEditorMarginsLR.setMaximum(2048)
        self.spnEditorMarginsLR.setObjectName("spnEditorMarginsLR")
        self.formLayout_11.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.spnEditorMarginsLR)
        self.label_55 = QtWidgets.QLabel(self.groupBox_161)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_55.setFont(font)
        self.label_55.setObjectName("label_55")
        self.formLayout_11.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_55)
        self.spnEditorMarginsTB = QtWidgets.QSpinBox(self.groupBox_161)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.spnEditorMarginsTB.setFont(font)
        self.spnEditorMarginsTB.setMaximum(2048)
        self.spnEditorMarginsTB.setObjectName("spnEditorMarginsTB")
        self.formLayout_11.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.spnEditorMarginsTB)
        self.verticalLayout_21.addWidget(self.groupBox_161)
        self.horizontalLayout_4.addLayout(self.verticalLayout_21)
        self.verticalLayout_22 = QtWidgets.QVBoxLayout()
        self.verticalLayout_22.setObjectName("verticalLayout_22")
        self.groupBox_13 = QtWidgets.QGroupBox(self.tab_4)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.groupBox_13.setFont(font)
        self.groupBox_13.setObjectName("groupBox_13")
        self.formLayout_9 = QtWidgets.QFormLayout(self.groupBox_13)
        self.formLayout_9.setObjectName("formLayout_9")
        self.label_35 = QtWidgets.QLabel(self.groupBox_13)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_35.setFont(font)
        self.label_35.setObjectName("label_35")
        self.formLayout_9.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_35)
        self.cmbEditorAlignment = QtWidgets.QComboBox(self.groupBox_13)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.cmbEditorAlignment.setFont(font)
        self.cmbEditorAlignment.setObjectName("cmbEditorAlignment")
        icon = QtGui.QIcon.fromTheme("format-justify-left")
        self.cmbEditorAlignment.addItem(icon, "")
        icon = QtGui.QIcon.fromTheme("format-justify-center")
        self.cmbEditorAlignment.addItem(icon, "")
        icon = QtGui.QIcon.fromTheme("format-justify-right")
        self.cmbEditorAlignment.addItem(icon, "")
        icon = QtGui.QIcon.fromTheme("format-justify-fill")
        self.cmbEditorAlignment.addItem(icon, "")
        self.formLayout_9.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.cmbEditorAlignment)
        self.label_40 = QtWidgets.QLabel(self.groupBox_13)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_40.setFont(font)
        self.label_40.setObjectName("label_40")
        self.formLayout_9.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_40)
        self.cmbEditorLineSpacing = QtWidgets.QComboBox(self.groupBox_13)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.cmbEditorLineSpacing.setFont(font)
        self.cmbEditorLineSpacing.setObjectName("cmbEditorLineSpacing")
        self.cmbEditorLineSpacing.addItem("")
        self.cmbEditorLineSpacing.addItem("")
        self.cmbEditorLineSpacing.addItem("")
        self.cmbEditorLineSpacing.addItem("")
        self.formLayout_9.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.cmbEditorLineSpacing)
        self.spnEditorLineSpacing = QtWidgets.QSpinBox(self.groupBox_13)
        self.spnEditorLineSpacing.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spnEditorLineSpacing.sizePolicy().hasHeightForWidth())
        self.spnEditorLineSpacing.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.spnEditorLineSpacing.setFont(font)
        self.spnEditorLineSpacing.setMinimum(50)
        self.spnEditorLineSpacing.setMaximum(999)
        self.spnEditorLineSpacing.setProperty("value", 100)
        self.spnEditorLineSpacing.setObjectName("spnEditorLineSpacing")
        self.formLayout_9.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.spnEditorLineSpacing)
        self.label_42 = QtWidgets.QLabel(self.groupBox_13)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_42.setFont(font)
        self.label_42.setObjectName("label_42")
        self.formLayout_9.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_42)
        self.spnEditorTabWidth = QtWidgets.QSpinBox(self.groupBox_13)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spnEditorTabWidth.sizePolicy().hasHeightForWidth())
        self.spnEditorTabWidth.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.spnEditorTabWidth.setFont(font)
        self.spnEditorTabWidth.setMinimum(0)
        self.spnEditorTabWidth.setMaximum(199)
        self.spnEditorTabWidth.setProperty("value", 20)
        self.spnEditorTabWidth.setObjectName("spnEditorTabWidth")
        self.formLayout_9.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.spnEditorTabWidth)
        self.chkEditorIndent = QtWidgets.QCheckBox(self.groupBox_13)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.chkEditorIndent.sizePolicy().hasHeightForWidth())
        self.chkEditorIndent.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.chkEditorIndent.setFont(font)
        self.chkEditorIndent.setObjectName("chkEditorIndent")
        self.formLayout_9.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.chkEditorIndent)
        self.label_41 = QtWidgets.QLabel(self.groupBox_13)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_41.setFont(font)
        self.label_41.setObjectName("label_41")
        self.formLayout_9.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.label_41)
        self.spnEditorParaAbove = QtWidgets.QSpinBox(self.groupBox_13)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spnEditorParaAbove.sizePolicy().hasHeightForWidth())
        self.spnEditorParaAbove.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.spnEditorParaAbove.setFont(font)
        self.spnEditorParaAbove.setMinimum(0)
        self.spnEditorParaAbove.setMaximum(199)
        self.spnEditorParaAbove.setProperty("value", 5)
        self.spnEditorParaAbove.setObjectName("spnEditorParaAbove")
        self.formLayout_9.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.spnEditorParaAbove)
        self.spnEditorParaBelow = QtWidgets.QSpinBox(self.groupBox_13)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spnEditorParaBelow.sizePolicy().hasHeightForWidth())
        self.spnEditorParaBelow.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.spnEditorParaBelow.setFont(font)
        self.spnEditorParaBelow.setMinimum(0)
        self.spnEditorParaBelow.setMaximum(199)
        self.spnEditorParaBelow.setProperty("value", 5)
        self.spnEditorParaBelow.setObjectName("spnEditorParaBelow")
        self.formLayout_9.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.spnEditorParaBelow)
        self.verticalLayout_22.addWidget(self.groupBox_13)
        self.groupBox_15 = QtWidgets.QGroupBox(self.tab_4)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.groupBox_15.setFont(font)
        self.groupBox_15.setObjectName("groupBox_15")
        self.formLayout_10 = QtWidgets.QFormLayout(self.groupBox_15)
        self.formLayout_10.setObjectName("formLayout_10")
        self.chkEditorCursorWidth = QtWidgets.QCheckBox(self.groupBox_15)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.chkEditorCursorWidth.setFont(font)
        self.chkEditorCursorWidth.setObjectName("chkEditorCursorWidth")
        self.formLayout_10.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.chkEditorCursorWidth)
        self.spnEditorCursorWidth = QtWidgets.QSpinBox(self.groupBox_15)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.spnEditorCursorWidth.setFont(font)
        self.spnEditorCursorWidth.setMinimum(0)
        self.spnEditorCursorWidth.setMaximum(99)
        self.spnEditorCursorWidth.setProperty("value", 9)
        self.spnEditorCursorWidth.setObjectName("spnEditorCursorWidth")
        self.formLayout_10.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.spnEditorCursorWidth)
        self.chkEditorNoBlinking = QtWidgets.QCheckBox(self.groupBox_15)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.chkEditorNoBlinking.setFont(font)
        self.chkEditorNoBlinking.setObjectName("chkEditorNoBlinking")
        self.formLayout_10.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.chkEditorNoBlinking)
        self.chkEditorTypeWriterMode = QtWidgets.QCheckBox(self.groupBox_15)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.chkEditorTypeWriterMode.setFont(font)
        self.chkEditorTypeWriterMode.setObjectName("chkEditorTypeWriterMode")
        self.formLayout_10.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.chkEditorTypeWriterMode)
        self.label_52 = QtWidgets.QLabel(self.groupBox_15)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_52.setFont(font)
        self.label_52.setObjectName("label_52")
        self.formLayout_10.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_52)
        self.cmbEditorFocusMode = QtWidgets.QComboBox(self.groupBox_15)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.cmbEditorFocusMode.setFont(font)
        self.cmbEditorFocusMode.setObjectName("cmbEditorFocusMode")
        self.cmbEditorFocusMode.addItem("")
        self.cmbEditorFocusMode.addItem("")
        self.cmbEditorFocusMode.addItem("")
        self.cmbEditorFocusMode.addItem("")
        self.formLayout_10.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.cmbEditorFocusMode)
        self.verticalLayout_22.addWidget(self.groupBox_15)
        self.horizontalLayout_4.addLayout(self.verticalLayout_22)
        icon = QtGui.QIcon.fromTheme("view-text")
        self.tabViews.addTab(self.tab_4, icon, "")
        self.verticalLayout_9.addWidget(self.tabViews)
        self.stack.addWidget(self.stackedWidgetPage2)
        self.stackedWidgetPage3 = QtWidgets.QWidget()
        self.stackedWidgetPage3.setObjectName("stackedWidgetPage3")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.stackedWidgetPage3)
        self.verticalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.lblTitleLabels = QtWidgets.QLabel(self.stackedWidgetPage3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lblTitleLabels.sizePolicy().hasHeightForWidth())
        self.lblTitleLabels.setSizePolicy(sizePolicy)
        self.lblTitleLabels.setAlignment(QtCore.Qt.AlignCenter)
        self.lblTitleLabels.setObjectName("lblTitleLabels")
        self.verticalLayout_3.addWidget(self.lblTitleLabels)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.lstLabels = QtWidgets.QListView(self.stackedWidgetPage3)
        self.lstLabels.setObjectName("lstLabels")
        self.horizontalLayout_2.addWidget(self.lstLabels)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.btnLabelColor = QtWidgets.QPushButton(self.stackedWidgetPage3)
        self.btnLabelColor.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnLabelColor.sizePolicy().hasHeightForWidth())
        self.btnLabelColor.setSizePolicy(sizePolicy)
        self.btnLabelColor.setMinimumSize(QtCore.QSize(64, 64))
        self.btnLabelColor.setMaximumSize(QtCore.QSize(64, 64))
        self.btnLabelColor.setText("")
        self.btnLabelColor.setIconSize(QtCore.QSize(64, 64))
        self.btnLabelColor.setObjectName("btnLabelColor")
        self.verticalLayout_2.addWidget(self.btnLabelColor)
        spacerItem8 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem8)
        self.horizontalLayout_2.addLayout(self.verticalLayout_2)
        self.verticalLayout_3.addLayout(self.horizontalLayout_2)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.btnLabelAdd = QtWidgets.QPushButton(self.stackedWidgetPage3)
        self.btnLabelAdd.setText("")
        icon = QtGui.QIcon.fromTheme("list-add")
        self.btnLabelAdd.setIcon(icon)
        self.btnLabelAdd.setObjectName("btnLabelAdd")
        self.horizontalLayout.addWidget(self.btnLabelAdd)
        self.btnLabelRemove = QtWidgets.QPushButton(self.stackedWidgetPage3)
        self.btnLabelRemove.setText("")
        icon = QtGui.QIcon.fromTheme("list-remove")
        self.btnLabelRemove.setIcon(icon)
        self.btnLabelRemove.setObjectName("btnLabelRemove")
        self.horizontalLayout.addWidget(self.btnLabelRemove)
        spacerItem9 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem9)
        self.verticalLayout_3.addLayout(self.horizontalLayout)
        self.stack.addWidget(self.stackedWidgetPage3)
        self.stackedWidgetPage4 = QtWidgets.QWidget()
        self.stackedWidgetPage4.setObjectName("stackedWidgetPage4")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.stackedWidgetPage4)
        self.verticalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.lblTitleStatus = QtWidgets.QLabel(self.stackedWidgetPage4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lblTitleStatus.sizePolicy().hasHeightForWidth())
        self.lblTitleStatus.setSizePolicy(sizePolicy)
        self.lblTitleStatus.setAlignment(QtCore.Qt.AlignCenter)
        self.lblTitleStatus.setObjectName("lblTitleStatus")
        self.verticalLayout_4.addWidget(self.lblTitleStatus)
        self.lstStatus = QtWidgets.QListView(self.stackedWidgetPage4)
        self.lstStatus.setObjectName("lstStatus")
        self.verticalLayout_4.addWidget(self.lstStatus)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.btnStatusAdd = QtWidgets.QPushButton(self.stackedWidgetPage4)
        self.btnStatusAdd.setText("")
        icon = QtGui.QIcon.fromTheme("list-add")
        self.btnStatusAdd.setIcon(icon)
        self.btnStatusAdd.setObjectName("btnStatusAdd")
        self.horizontalLayout_3.addWidget(self.btnStatusAdd)
        self.btnStatusRemove = QtWidgets.QPushButton(self.stackedWidgetPage4)
        self.btnStatusRemove.setText("")
        icon = QtGui.QIcon.fromTheme("list-remove")
        self.btnStatusRemove.setIcon(icon)
        self.btnStatusRemove.setObjectName("btnStatusRemove")
        self.horizontalLayout_3.addWidget(self.btnStatusRemove)
        spacerItem10 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem10)
        self.verticalLayout_4.addLayout(self.horizontalLayout_3)
        self.stack.addWidget(self.stackedWidgetPage4)
        self.page = QtWidgets.QWidget()
        self.page.setObjectName("page")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.page)
        self.verticalLayout_10.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.lblTitleFullscreen = QtWidgets.QLabel(self.page)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lblTitleFullscreen.sizePolicy().hasHeightForWidth())
        self.lblTitleFullscreen.setSizePolicy(sizePolicy)
        self.lblTitleFullscreen.setAlignment(QtCore.Qt.AlignCenter)
        self.lblTitleFullscreen.setObjectName("lblTitleFullscreen")
        self.verticalLayout_10.addWidget(self.lblTitleFullscreen)
        self.themeStack = QtWidgets.QStackedWidget(self.page)
        self.themeStack.setObjectName("themeStack")
        self.stackedWidgetPage1_3 = QtWidgets.QWidget()
        self.stackedWidgetPage1_3.setObjectName("stackedWidgetPage1_3")
        self.verticalLayout_12 = QtWidgets.QVBoxLayout(self.stackedWidgetPage1_3)
        self.verticalLayout_12.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_12.setObjectName("verticalLayout_12")
        self.lstThemes = QtWidgets.QListWidget(self.stackedWidgetPage1_3)
        self.lstThemes.setMovement(QtWidgets.QListView.Static)
        self.lstThemes.setResizeMode(QtWidgets.QListView.Adjust)
        self.lstThemes.setViewMode(QtWidgets.QListView.IconMode)
        self.lstThemes.setUniformItemSizes(True)
        self.lstThemes.setObjectName("lstThemes")
        self.verticalLayout_12.addWidget(self.lstThemes)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.btnThemeAdd = QtWidgets.QPushButton(self.stackedWidgetPage1_3)
        icon = QtGui.QIcon.fromTheme("list-add")
        self.btnThemeAdd.setIcon(icon)
        self.btnThemeAdd.setObjectName("btnThemeAdd")
        self.horizontalLayout_6.addWidget(self.btnThemeAdd)
        self.btnThemeEdit = QtWidgets.QPushButton(self.stackedWidgetPage1_3)
        self.btnThemeEdit.setEnabled(False)
        self.btnThemeEdit.setObjectName("btnThemeEdit")
        self.horizontalLayout_6.addWidget(self.btnThemeEdit)
        self.btnThemeRemove = QtWidgets.QPushButton(self.stackedWidgetPage1_3)
        self.btnThemeRemove.setEnabled(False)
        icon = QtGui.QIcon.fromTheme("list-remove")
        self.btnThemeRemove.setIcon(icon)
        self.btnThemeRemove.setObjectName("btnThemeRemove")
        self.horizontalLayout_6.addWidget(self.btnThemeRemove)
        spacerItem11 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem11)
        self.verticalLayout_12.addLayout(self.horizontalLayout_6)
        self.themeStack.addWidget(self.stackedWidgetPage1_3)
        self.stackedWidgetPage2_3 = QtWidgets.QWidget()
        self.stackedWidgetPage2_3.setObjectName("stackedWidgetPage2_3")
        self.verticalLayout_13 = QtWidgets.QVBoxLayout(self.stackedWidgetPage2_3)
        self.verticalLayout_13.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_13.setObjectName("verticalLayout_13")
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.label_33 = QtWidgets.QLabel(self.stackedWidgetPage2_3)
        self.label_33.setObjectName("label_33")
        self.horizontalLayout_10.addWidget(self.label_33)
        self.txtThemeName = QtWidgets.QLineEdit(self.stackedWidgetPage2_3)
        self.txtThemeName.setObjectName("txtThemeName")
        self.horizontalLayout_10.addWidget(self.txtThemeName)
        self.btnThemeEditOK = QtWidgets.QPushButton(self.stackedWidgetPage2_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnThemeEditOK.sizePolicy().hasHeightForWidth())
        self.btnThemeEditOK.setSizePolicy(sizePolicy)
        self.btnThemeEditOK.setObjectName("btnThemeEditOK")
        self.horizontalLayout_10.addWidget(self.btnThemeEditOK)
        self.btnThemeEditCancel = QtWidgets.QPushButton(self.stackedWidgetPage2_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnThemeEditCancel.sizePolicy().hasHeightForWidth())
        self.btnThemeEditCancel.setSizePolicy(sizePolicy)
        self.btnThemeEditCancel.setObjectName("btnThemeEditCancel")
        self.horizontalLayout_10.addWidget(self.btnThemeEditCancel)
        self.verticalLayout_13.addLayout(self.horizontalLayout_10)
        self.line = QtWidgets.QFrame(self.stackedWidgetPage2_3)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.verticalLayout_13.addWidget(self.line)
        self.splitter = QtWidgets.QSplitter(self.stackedWidgetPage2_3)
        self.splitter.setOrientation(QtCore.Qt.Horizontal)
        self.splitter.setHandleWidth(3)
        self.splitter.setChildrenCollapsible(False)
        self.splitter.setObjectName("splitter")
        self.layoutWidget = QtWidgets.QWidget(self.splitter)
        self.layoutWidget.setObjectName("layoutWidget")
        self.verticalLayout_14 = QtWidgets.QVBoxLayout(self.layoutWidget)
        self.verticalLayout_14.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_14.setObjectName("verticalLayout_14")
        self.cmbThemeEdit = QtWidgets.QComboBox(self.layoutWidget)
        self.cmbThemeEdit.setObjectName("cmbThemeEdit")
        self.cmbThemeEdit.addItem("")
        self.cmbThemeEdit.addItem("")
        self.cmbThemeEdit.addItem("")
        self.cmbThemeEdit.addItem("")
        self.verticalLayout_14.addWidget(self.cmbThemeEdit)
        self.themeEditStack = QtWidgets.QStackedWidget(self.layoutWidget)
        self.themeEditStack.setObjectName("themeEditStack")
        self.stackedWidgetPage1_2 = QtWidgets.QWidget()
        self.stackedWidgetPage1_2.setObjectName("stackedWidgetPage1_2")
        self.formLayout_4 = QtWidgets.QFormLayout(self.stackedWidgetPage1_2)
        self.formLayout_4.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout_4.setObjectName("formLayout_4")
        self.label_17 = QtWidgets.QLabel(self.stackedWidgetPage1_2)
        self.label_17.setObjectName("label_17")
        self.formLayout_4.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_17)
        self.btnThemWindowBackgroundColor = QtWidgets.QPushButton(self.stackedWidgetPage1_2)
        self.btnThemWindowBackgroundColor.setText("")
        self.btnThemWindowBackgroundColor.setObjectName("btnThemWindowBackgroundColor")
        self.formLayout_4.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.btnThemWindowBackgroundColor)
        self.label_18 = QtWidgets.QLabel(self.stackedWidgetPage1_2)
        self.label_18.setObjectName("label_18")
        self.formLayout_4.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_18)
        self.cmbThemeBackgroundImage = QtWidgets.QComboBox(self.stackedWidgetPage1_2)
        self.cmbThemeBackgroundImage.setObjectName("cmbThemeBackgroundImage")
        self.formLayout_4.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.cmbThemeBackgroundImage)
        self.label_19 = QtWidgets.QLabel(self.stackedWidgetPage1_2)
        self.label_19.setObjectName("label_19")
        self.formLayout_4.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_19)
        self.cmbThemBackgroundType = QtWidgets.QComboBox(self.stackedWidgetPage1_2)
        self.cmbThemBackgroundType.setObjectName("cmbThemBackgroundType")
        self.cmbThemBackgroundType.addItem("")
        self.cmbThemBackgroundType.addItem("")
        self.cmbThemBackgroundType.addItem("")
        self.cmbThemBackgroundType.addItem("")
        self.cmbThemBackgroundType.addItem("")
        self.cmbThemBackgroundType.addItem("")
        self.formLayout_4.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.cmbThemBackgroundType)
        self.themeEditStack.addWidget(self.stackedWidgetPage1_2)
        self.stackedWidgetPage2_2 = QtWidgets.QWidget()
        self.stackedWidgetPage2_2.setObjectName("stackedWidgetPage2_2")
        self.formLayout_5 = QtWidgets.QFormLayout(self.stackedWidgetPage2_2)
        self.formLayout_5.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout_5.setObjectName("formLayout_5")
        self.label_20 = QtWidgets.QLabel(self.stackedWidgetPage2_2)
        self.label_20.setObjectName("label_20")
        self.formLayout_5.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_20)
        self.btnThemeTextBackgroundColor = QtWidgets.QPushButton(self.stackedWidgetPage2_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnThemeTextBackgroundColor.sizePolicy().hasHeightForWidth())
        self.btnThemeTextBackgroundColor.setSizePolicy(sizePolicy)
        self.btnThemeTextBackgroundColor.setText("")
        self.btnThemeTextBackgroundColor.setObjectName("btnThemeTextBackgroundColor")
        self.formLayout_5.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.btnThemeTextBackgroundColor)
        self.label_21 = QtWidgets.QLabel(self.stackedWidgetPage2_2)
        self.label_21.setObjectName("label_21")
        self.formLayout_5.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_21)
        self.spnThemeTextBackgroundOpacity = QtWidgets.QSpinBox(self.stackedWidgetPage2_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spnThemeTextBackgroundOpacity.sizePolicy().hasHeightForWidth())
        self.spnThemeTextBackgroundOpacity.setSizePolicy(sizePolicy)
        self.spnThemeTextBackgroundOpacity.setMaximum(100)
        self.spnThemeTextBackgroundOpacity.setProperty("value", 70)
        self.spnThemeTextBackgroundOpacity.setObjectName("spnThemeTextBackgroundOpacity")
        self.formLayout_5.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.spnThemeTextBackgroundOpacity)
        self.label_22 = QtWidgets.QLabel(self.stackedWidgetPage2_2)
        self.label_22.setObjectName("label_22")
        self.formLayout_5.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_22)
        self.cmbThemeTextPosition = QtWidgets.QComboBox(self.stackedWidgetPage2_2)
        self.cmbThemeTextPosition.setObjectName("cmbThemeTextPosition")
        self.cmbThemeTextPosition.addItem("")
        self.cmbThemeTextPosition.addItem("")
        self.cmbThemeTextPosition.addItem("")
        self.cmbThemeTextPosition.addItem("")
        self.formLayout_5.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.cmbThemeTextPosition)
        self.label_23 = QtWidgets.QLabel(self.stackedWidgetPage2_2)
        self.label_23.setObjectName("label_23")
        self.formLayout_5.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_23)
        self.spnThemeTextWidth = QtWidgets.QSpinBox(self.stackedWidgetPage2_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spnThemeTextWidth.sizePolicy().hasHeightForWidth())
        self.spnThemeTextWidth.setSizePolicy(sizePolicy)
        self.spnThemeTextWidth.setMinimum(300)
        self.spnThemeTextWidth.setMaximum(9999)
        self.spnThemeTextWidth.setProperty("value", 700)
        self.spnThemeTextWidth.setObjectName("spnThemeTextWidth")
        self.formLayout_5.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.spnThemeTextWidth)
        self.spnThemeTextRadius = QtWidgets.QSpinBox(self.stackedWidgetPage2_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spnThemeTextRadius.sizePolicy().hasHeightForWidth())
        self.spnThemeTextRadius.setSizePolicy(sizePolicy)
        self.spnThemeTextRadius.setMinimum(0)
        self.spnThemeTextRadius.setMaximum(100)
        self.spnThemeTextRadius.setProperty("value", 5)
        self.spnThemeTextRadius.setObjectName("spnThemeTextRadius")
        self.formLayout_5.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.spnThemeTextRadius)
        self.label_24 = QtWidgets.QLabel(self.stackedWidgetPage2_2)
        self.label_24.setObjectName("label_24")
        self.formLayout_5.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.label_24)
        self.label_25 = QtWidgets.QLabel(self.stackedWidgetPage2_2)
        self.label_25.setObjectName("label_25")
        self.formLayout_5.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.label_25)
        self.spnThemeTextMargins = QtWidgets.QSpinBox(self.stackedWidgetPage2_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spnThemeTextMargins.sizePolicy().hasHeightForWidth())
        self.spnThemeTextMargins.setSizePolicy(sizePolicy)
        self.spnThemeTextMargins.setMinimum(0)
        self.spnThemeTextMargins.setMaximum(199)
        self.spnThemeTextMargins.setProperty("value", 20)
        self.spnThemeTextMargins.setObjectName("spnThemeTextMargins")
        self.formLayout_5.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.spnThemeTextMargins)
        self.label_34 = QtWidgets.QLabel(self.stackedWidgetPage2_2)
        self.label_34.setObjectName("label_34")
        self.formLayout_5.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.label_34)
        self.spnThemeTextPadding = QtWidgets.QSpinBox(self.stackedWidgetPage2_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spnThemeTextPadding.sizePolicy().hasHeightForWidth())
        self.spnThemeTextPadding.setSizePolicy(sizePolicy)
        self.spnThemeTextPadding.setMinimum(0)
        self.spnThemeTextPadding.setMaximum(199)
        self.spnThemeTextPadding.setProperty("value", 10)
        self.spnThemeTextPadding.setObjectName("spnThemeTextPadding")
        self.formLayout_5.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.spnThemeTextPadding)
        self.themeEditStack.addWidget(self.stackedWidgetPage2_2)
        self.page_2 = QtWidgets.QWidget()
        self.page_2.setObjectName("page_2")
        self.formLayout_7 = QtWidgets.QFormLayout(self.page_2)
        self.formLayout_7.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout_7.setObjectName("formLayout_7")
        self.label_29 = QtWidgets.QLabel(self.page_2)
        self.label_29.setObjectName("label_29")
        self.formLayout_7.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_29)
        self.btnThemeTextColor = QtWidgets.QPushButton(self.page_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnThemeTextColor.sizePolicy().hasHeightForWidth())
        self.btnThemeTextColor.setSizePolicy(sizePolicy)
        self.btnThemeTextColor.setText("")
        self.btnThemeTextColor.setObjectName("btnThemeTextColor")
        self.formLayout_7.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.btnThemeTextColor)
        self.label_30 = QtWidgets.QLabel(self.page_2)
        self.label_30.setObjectName("label_30")
        self.formLayout_7.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_30)
        self.cmbThemeFont = QtWidgets.QFontComboBox(self.page_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cmbThemeFont.sizePolicy().hasHeightForWidth())
        self.cmbThemeFont.setSizePolicy(sizePolicy)
        self.cmbThemeFont.setMaximumSize(QtCore.QSize(150, 16777215))
        self.cmbThemeFont.setObjectName("cmbThemeFont")
        self.formLayout_7.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.cmbThemeFont)
        self.label_31 = QtWidgets.QLabel(self.page_2)
        self.label_31.setObjectName("label_31")
        self.formLayout_7.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_31)
        self.cmbThemeFontSize = QtWidgets.QComboBox(self.page_2)
        self.cmbThemeFontSize.setEditable(True)
        self.cmbThemeFontSize.setObjectName("cmbThemeFontSize")
        self.formLayout_7.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.cmbThemeFontSize)
        self.label_32 = QtWidgets.QLabel(self.page_2)
        self.label_32.setObjectName("label_32")
        self.formLayout_7.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_32)
        self.btnThemeMisspelledColor = QtWidgets.QPushButton(self.page_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnThemeMisspelledColor.sizePolicy().hasHeightForWidth())
        self.btnThemeMisspelledColor.setSizePolicy(sizePolicy)
        self.btnThemeMisspelledColor.setText("")
        self.btnThemeMisspelledColor.setObjectName("btnThemeMisspelledColor")
        self.formLayout_7.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.btnThemeMisspelledColor)
        self.themeEditStack.addWidget(self.page_2)
        self.stackedWidgetPage3_2 = QtWidgets.QWidget()
        self.stackedWidgetPage3_2.setObjectName("stackedWidgetPage3_2")
        self.formLayout_6 = QtWidgets.QFormLayout(self.stackedWidgetPage3_2)
        self.formLayout_6.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout_6.setObjectName("formLayout_6")
        self.label_26 = QtWidgets.QLabel(self.stackedWidgetPage3_2)
        self.label_26.setObjectName("label_26")
        self.formLayout_6.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_26)
        self.cmbThemeLineSpacing = QtWidgets.QComboBox(self.stackedWidgetPage3_2)
        self.cmbThemeLineSpacing.setObjectName("cmbThemeLineSpacing")
        self.cmbThemeLineSpacing.addItem("")
        self.cmbThemeLineSpacing.addItem("")
        self.cmbThemeLineSpacing.addItem("")
        self.cmbThemeLineSpacing.addItem("")
        self.formLayout_6.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.cmbThemeLineSpacing)
        self.spnThemeLineSpacing = QtWidgets.QSpinBox(self.stackedWidgetPage3_2)
        self.spnThemeLineSpacing.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spnThemeLineSpacing.sizePolicy().hasHeightForWidth())
        self.spnThemeLineSpacing.setSizePolicy(sizePolicy)
        self.spnThemeLineSpacing.setMinimum(50)
        self.spnThemeLineSpacing.setMaximum(999)
        self.spnThemeLineSpacing.setProperty("value", 100)
        self.spnThemeLineSpacing.setObjectName("spnThemeLineSpacing")
        self.formLayout_6.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.spnThemeLineSpacing)
        self.label_27 = QtWidgets.QLabel(self.stackedWidgetPage3_2)
        self.label_27.setObjectName("label_27")
        self.formLayout_6.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_27)
        self.spnThemeTabWidth = QtWidgets.QSpinBox(self.stackedWidgetPage3_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spnThemeTabWidth.sizePolicy().hasHeightForWidth())
        self.spnThemeTabWidth.setSizePolicy(sizePolicy)
        self.spnThemeTabWidth.setMinimum(0)
        self.spnThemeTabWidth.setMaximum(199)
        self.spnThemeTabWidth.setProperty("value", 20)
        self.spnThemeTabWidth.setObjectName("spnThemeTabWidth")
        self.formLayout_6.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.spnThemeTabWidth)
        self.label_28 = QtWidgets.QLabel(self.stackedWidgetPage3_2)
        self.label_28.setObjectName("label_28")
        self.formLayout_6.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.label_28)
        self.spnThemeParaAbove = QtWidgets.QSpinBox(self.stackedWidgetPage3_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spnThemeParaAbove.sizePolicy().hasHeightForWidth())
        self.spnThemeParaAbove.setSizePolicy(sizePolicy)
        self.spnThemeParaAbove.setMinimum(0)
        self.spnThemeParaAbove.setMaximum(199)
        self.spnThemeParaAbove.setProperty("value", 5)
        self.spnThemeParaAbove.setObjectName("spnThemeParaAbove")
        self.formLayout_6.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.spnThemeParaAbove)
        self.spnThemeParaBelow = QtWidgets.QSpinBox(self.stackedWidgetPage3_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spnThemeParaBelow.sizePolicy().hasHeightForWidth())
        self.spnThemeParaBelow.setSizePolicy(sizePolicy)
        self.spnThemeParaBelow.setMinimum(0)
        self.spnThemeParaBelow.setMaximum(199)
        self.spnThemeParaBelow.setProperty("value", 5)
        self.spnThemeParaBelow.setObjectName("spnThemeParaBelow")
        self.formLayout_6.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.spnThemeParaBelow)
        self.chkThemeIndent = QtWidgets.QCheckBox(self.stackedWidgetPage3_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.chkThemeIndent.sizePolicy().hasHeightForWidth())
        self.chkThemeIndent.setSizePolicy(sizePolicy)
        self.chkThemeIndent.setObjectName("chkThemeIndent")
        self.formLayout_6.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.chkThemeIndent)
        self.cmbThemeAlignment = QtWidgets.QComboBox(self.stackedWidgetPage3_2)
        self.cmbThemeAlignment.setObjectName("cmbThemeAlignment")
        icon = QtGui.QIcon.fromTheme("format-justify-left")
        self.cmbThemeAlignment.addItem(icon, "")
        icon = QtGui.QIcon.fromTheme("format-justify-center")
        self.cmbThemeAlignment.addItem(icon, "")
        icon = QtGui.QIcon.fromTheme("format-justify-right")
        self.cmbThemeAlignment.addItem(icon, "")
        icon = QtGui.QIcon.fromTheme("format-justify-fill")
        self.cmbThemeAlignment.addItem(icon, "")
        self.formLayout_6.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.cmbThemeAlignment)
        self.label_53 = QtWidgets.QLabel(self.stackedWidgetPage3_2)
        self.label_53.setObjectName("label_53")
        self.formLayout_6.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_53)
        self.themeEditStack.addWidget(self.stackedWidgetPage3_2)
        self.verticalLayout_14.addWidget(self.themeEditStack)
        self.lblPreview = QtWidgets.QLabel(self.splitter)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lblPreview.sizePolicy().hasHeightForWidth())
        self.lblPreview.setSizePolicy(sizePolicy)
        self.lblPreview.setMinimumSize(QtCore.QSize(300, 200))
        self.lblPreview.setText("")
        self.lblPreview.setObjectName("lblPreview")
        self.verticalLayout_13.addWidget(self.splitter)
        self.themeStack.addWidget(self.stackedWidgetPage2_3)
        self.verticalLayout_10.addWidget(self.themeStack)
        self.stack.addWidget(self.page)
        self.horizontalLayout_8.addWidget(self.stack)

        self.retranslateUi(Settings)
        self.stack.setCurrentIndex(2)
        self.tabViews.setCurrentIndex(3)
        self.themeStack.setCurrentIndex(1)
        self.themeEditStack.setCurrentIndex(3)
        self.lstMenu.currentRowChanged['int'].connect(self.stack.setCurrentIndex)
        self.chkRevisionsKeep.toggled['bool'].connect(self.chkRevisionRemove.setEnabled)
        QtCore.QMetaObject.connectSlotsByName(Settings)

    def retranslateUi(self, Settings):
        _translate = QtCore.QCoreApplication.translate
        Settings.setWindowTitle(_translate("Settings", "Settings"))
        __sortingEnabled = self.lstMenu.isSortingEnabled()
        self.lstMenu.setSortingEnabled(False)
        item = self.lstMenu.item(0)
        item.setText(_translate("Settings", "General"))
        item = self.lstMenu.item(1)
        item.setText(_translate("Settings", "Revisions"))
        item = self.lstMenu.item(2)
        item.setText(_translate("Settings", "Views"))
        item = self.lstMenu.item(3)
        item.setText(_translate("Settings", "Labels"))
        item = self.lstMenu.item(4)
        item.setText(_translate("Settings", "Status"))
        item = self.lstMenu.item(5)
        item.setText(_translate("Settings", "Fullscreen"))
        self.lstMenu.setSortingEnabled(__sortingEnabled)
        self.lblTitleGeneral.setText(_translate("Settings", "General settings"))
        self.groupBox_2.setTitle(_translate("Settings", "Application settings"))
        self.label_56.setText(_translate("Settings", "Style:"))
        self.label_57.setText(_translate("Settings", "Language:"))
        self.label_58.setText(_translate("Settings", "Font size:"))
        self.label_2.setText(_translate("Settings", "Restarting Manuskript ensures all settings take effect."))
        self.groupBox_10.setTitle(_translate("Settings", "Loading"))
        self.chkAutoLoad.setText(_translate("Settings", "Automatically load last project on startup"))
        self.groupBox.setTitle(_translate("Settings", "Saving"))
        self.chkAutoSave.setText(_translate("Settings", "Automatically save every"))
        self.label.setText(_translate("Settings", "minutes."))
        self.chkAutoSaveNoChanges.setText(_translate("Settings", "If no changes during"))
        self.label_14.setText(_translate("Settings", "seconds."))
        self.chkSaveOnQuit.setText(_translate("Settings", "Save on project close"))
        self.chkSaveToZip.setToolTip(_translate("Settings", "<html><head/><body><p>If you check this option, your project will be saved as one single file. Easier to copy or backup, but does not allow collaborative editing, or versioning.<br/>If this is unchecked, your project will be saved as a folder containing many small files.</p></body></html>"))
        self.chkSaveToZip.setText(_translate("Settings", "Save to one single file"))
        self.lblTitleGeneral_2.setText(_translate("Settings", "Revisions"))
        self.label_44.setText(_translate("Settings", "Revisions are a way to keep track of modifications. For each text item, it stores any changes you make to the main text, allowing you to see and restoring previous versions."))
        self.chkRevisionsKeep.setText(_translate("Settings", "Keep revisions"))
        self.chkRevisionRemove.setTitle(_translate("Settings", "S&mart remove"))
        self.label_46.setText(_translate("Settings", "Keep:"))
        self.label_45.setText(_translate("Settings", "Smart remove allows you to keep only a certain number of revisions. It is strongly recommended to use it, lest you file will becomes full of thousands of insignificant changes."))
        self.label_50.setText(_translate("Settings", "revisions per day for the last month"))
        self.label_47.setText(_translate("Settings", "revisions per minute for the last 10 minutes"))
        self.label_49.setText(_translate("Settings", "revisions per hour for the last day"))
        self.label_48.setText(_translate("Settings", "revisions per 10 minutes for the last hour"))
        self.label_51.setText(_translate("Settings", "revisions per week till the end of time"))
        self.label_revisionDeprecation.setText(_translate("Settings", "<p><b>The Revisions feature has been at the source of many reported issues. In this version of Manuskript it has been turned off by default for new projects in order to provide the best experience.</b></p><p>Why aren\'t these issues fixed already? <a href=\"https://www.theologeek.ch/manuskript/contribute/\">We need your help to make Manuskript better!</a></p>"))
        self.lblTitleViews.setText(_translate("Settings", "Views settings"))
        self.groupBox_3.setTitle(_translate("Settings", "Colors"))
        self.label_3.setText(_translate("Settings", "Icon color:"))
        self.cmbTreeIcon.setItemText(0, _translate("Settings", "Nothing"))
        self.cmbTreeIcon.setItemText(1, _translate("Settings", "POV"))
        self.cmbTreeIcon.setItemText(2, _translate("Settings", "Label"))
        self.cmbTreeIcon.setItemText(3, _translate("Settings", "Progress"))
        self.cmbTreeIcon.setItemText(4, _translate("Settings", "Compile"))
        self.label_4.setText(_translate("Settings", "Text color:"))
        self.cmbTreeText.setItemText(0, _translate("Settings", "Nothing"))
        self.cmbTreeText.setItemText(1, _translate("Settings", "POV"))
        self.cmbTreeText.setItemText(2, _translate("Settings", "Label"))
        self.cmbTreeText.setItemText(3, _translate("Settings", "Progress"))
        self.cmbTreeText.setItemText(4, _translate("Settings", "Compile"))
        self.label_5.setText(_translate("Settings", "Background color:"))
        self.cmbTreeBackground.setItemText(0, _translate("Settings", "Nothing"))
        self.cmbTreeBackground.setItemText(1, _translate("Settings", "POV"))
        self.cmbTreeBackground.setItemText(2, _translate("Settings", "Label"))
        self.cmbTreeBackground.setItemText(3, _translate("Settings", "Progress"))
        self.cmbTreeBackground.setItemText(4, _translate("Settings", "Compile"))
        self.groupBox_16.setTitle(_translate("Settings", "Icon Size"))
        self.lblTreeIconSize.setText(_translate("Settings", "TextLabel"))
        self.groupBox_8.setTitle(_translate("Settings", "Folders"))
        self.rdoTreeItemCount.setText(_translate("Settings", "Show ite&m count"))
        self.rdoTreeWC.setText(_translate("Settings", "Show &word count"))
        self.rdoTreeProgress.setText(_translate("Settings", "S&how progress"))
        self.rdoTreeSummary.setText(_translate("Settings", "Show summar&y"))
        self.rdoTreeNothing.setText(_translate("Settings", "&Nothing"))
        self.groupBox_9.setTitle(_translate("Settings", "Text"))
        self.rdoTreeTextWC.setText(_translate("Settings", "&Show word count"))
        self.rdoTreeTextProgress.setText(_translate("Settings", "Show p&rogress"))
        self.rdoTreeTextSummary.setText(_translate("Settings", "Show summary"))
        self.rdoTreeTextNothing.setText(_translate("Settings", "Nothing"))
        self.tabViews.setTabText(self.tabViews.indexOf(self.tab), _translate("Settings", "Tree"))
        self.groupBox_4.setTitle(_translate("Settings", "Colors"))
        self.label_6.setText(_translate("Settings", "Icon color:"))
        self.cmbOutlineIcon.setItemText(0, _translate("Settings", "Nothing"))
        self.cmbOutlineIcon.setItemText(1, _translate("Settings", "POV"))
        self.cmbOutlineIcon.setItemText(2, _translate("Settings", "Label"))
        self.cmbOutlineIcon.setItemText(3, _translate("Settings", "Progress"))
        self.cmbOutlineIcon.setItemText(4, _translate("Settings", "Compile"))
        self.label_7.setText(_translate("Settings", "Text color:"))
        self.cmbOutlineText.setItemText(0, _translate("Settings", "Nothing"))
        self.cmbOutlineText.setItemText(1, _translate("Settings", "POV"))
        self.cmbOutlineText.setItemText(2, _translate("Settings", "Label"))
        self.cmbOutlineText.setItemText(3, _translate("Settings", "Progress"))
        self.cmbOutlineText.setItemText(4, _translate("Settings", "Compile"))
        self.cmbOutlineBackground.setItemText(0, _translate("Settings", "Nothing"))
        self.cmbOutlineBackground.setItemText(1, _translate("Settings", "POV"))
        self.cmbOutlineBackground.setItemText(2, _translate("Settings", "Label"))
        self.cmbOutlineBackground.setItemText(3, _translate("Settings", "Progress"))
        self.cmbOutlineBackground.setItemText(4, _translate("Settings", "Compile"))
        self.label_8.setText(_translate("Settings", "Background color:"))
        self.groupBox_6.setTitle(_translate("Settings", "Visible columns"))
        self.chkOutlineGoal.setText(_translate("Settings", "Goal"))
        self.chkOutlineWordCount.setText(_translate("Settings", "Word count"))
        self.chkOutlinePercentage.setText(_translate("Settings", "Percentage"))
        self.chkOutlineCompile.setText(_translate("Settings", "Compile"))
        self.chkOutlineStatus.setText(_translate("Settings", "Status"))
        self.chkOutlineLabel.setText(_translate("Settings", "Label"))
        self.chkOutlinePOV.setText(_translate("Settings", "POV"))
        self.chkOutlineTitle.setText(_translate("Settings", "Title"))
        self.tabViews.setTabText(self.tabViews.indexOf(self.tab_2), _translate("Settings", "Outline"))
        self.groupBox_7.setTitle(_translate("Settings", "Background"))
        self.label_15.setText(_translate("Settings", "Color:"))
        self.btnCorkColor.setShortcut(_translate("Settings", "Ctrl+S"))
        self.label_16.setText(_translate("Settings", "Image:"))
        self.groupBox_11.setTitle(_translate("Settings", "Style"))
        self.rdoCorkOldStyle.setText(_translate("Settings", "Old st&yle"))
        self.rdoCorkNewStyle.setText(_translate("Settings", "&New style"))
        self.groupBox_5.setTitle(_translate("Settings", "Item colors"))
        self.label_9.setText(_translate("Settings", "Icon color:"))
        self.cmbCorkIcon.setItemText(0, _translate("Settings", "Nothing"))
        self.cmbCorkIcon.setItemText(1, _translate("Settings", "POV"))
        self.cmbCorkIcon.setItemText(2, _translate("Settings", "Label"))
        self.cmbCorkIcon.setItemText(3, _translate("Settings", "Progress"))
        self.cmbCorkIcon.setItemText(4, _translate("Settings", "Compile"))
        self.label_10.setText(_translate("Settings", "Text color:"))
        self.cmbCorkText.setItemText(0, _translate("Settings", "Nothing"))
        self.cmbCorkText.setItemText(1, _translate("Settings", "POV"))
        self.cmbCorkText.setItemText(2, _translate("Settings", "Label"))
        self.cmbCorkText.setItemText(3, _translate("Settings", "Progress"))
        self.cmbCorkText.setItemText(4, _translate("Settings", "Compile"))
        self.label_11.setText(_translate("Settings", "Background color:"))
        self.cmbCorkBackground.setItemText(0, _translate("Settings", "Nothing"))
        self.cmbCorkBackground.setItemText(1, _translate("Settings", "POV"))
        self.cmbCorkBackground.setItemText(2, _translate("Settings", "Label"))
        self.cmbCorkBackground.setItemText(3, _translate("Settings", "Progress"))
        self.cmbCorkBackground.setItemText(4, _translate("Settings", "Compile"))
        self.label_12.setText(_translate("Settings", "Border color:"))
        self.cmbCorkBorder.setItemText(0, _translate("Settings", "Nothing"))
        self.cmbCorkBorder.setItemText(1, _translate("Settings", "POV"))
        self.cmbCorkBorder.setItemText(2, _translate("Settings", "Label"))
        self.cmbCorkBorder.setItemText(3, _translate("Settings", "Progress"))
        self.cmbCorkBorder.setItemText(4, _translate("Settings", "Compile"))
        self.label_13.setText(_translate("Settings", "Corner color:"))
        self.cmbCorkCorner.setItemText(0, _translate("Settings", "Nothing"))
        self.cmbCorkCorner.setItemText(1, _translate("Settings", "POV"))
        self.cmbCorkCorner.setItemText(2, _translate("Settings", "Label"))
        self.cmbCorkCorner.setItemText(3, _translate("Settings", "Progress"))
        self.cmbCorkCorner.setItemText(4, _translate("Settings", "Compile"))
        self.tabViews.setTabText(self.tabViews.indexOf(self.tab_3), _translate("Settings", "Index cards"))
        self.groupBox_17.setTitle(_translate("Settings", "Colors"))
        self.label_43.setText(_translate("Settings", "Background:"))
        self.chkEditorBackgroundTransparent.setText(_translate("Settings", "Transparent"))
        self.label_37.setText(_translate("Settings", "Color:"))
        self.btnEditorColorDefault.setText(_translate("Settings", "Restore defaults"))
        self.groupBox_12.setTitle(_translate("Settings", "Font"))
        self.label_39.setText(_translate("Settings", "Family:"))
        self.label_38.setText(_translate("Settings", "Size:"))
        self.label_36.setText(_translate("Settings", "Misspelled:"))
        self.groupBox_161.setTitle(_translate("Settings", "Text area"))
        self.chkEditorMaxWidth.setText(_translate("Settings", "Max width"))
        self.spnEditorMaxWidth.setSuffix(_translate("Settings", " px"))
        self.label_54.setText(_translate("Settings", "Left/Right margins:"))
        self.spnEditorMarginsLR.setSuffix(_translate("Settings", " px"))
        self.label_55.setText(_translate("Settings", "Top/Bottom margins:"))
        self.spnEditorMarginsTB.setSuffix(_translate("Settings", " px"))
        self.groupBox_13.setTitle(_translate("Settings", "Paragraphs"))
        self.label_35.setText(_translate("Settings", "Alignment:"))
        self.cmbEditorAlignment.setItemText(0, _translate("Settings", "Left"))
        self.cmbEditorAlignment.setItemText(1, _translate("Settings", "Center"))
        self.cmbEditorAlignment.setItemText(2, _translate("Settings", "Right"))
        self.cmbEditorAlignment.setItemText(3, _translate("Settings", "Justify"))
        self.label_40.setText(_translate("Settings", "Line spacing:"))
        self.cmbEditorLineSpacing.setItemText(0, _translate("Settings", "Single"))
        self.cmbEditorLineSpacing.setItemText(1, _translate("Settings", "1.5 lines"))
        self.cmbEditorLineSpacing.setItemText(2, _translate("Settings", "Double"))
        self.cmbEditorLineSpacing.setItemText(3, _translate("Settings", "Proportional"))
        self.spnEditorLineSpacing.setSuffix(_translate("Settings", "%"))
        self.label_42.setText(_translate("Settings", "Tab width:"))
        self.spnEditorTabWidth.setSuffix(_translate("Settings", " px"))
        self.chkEditorIndent.setText(_translate("Settings", "Indent 1st line"))
        self.label_41.setText(_translate("Settings", "Spacing:"))
        self.spnEditorParaAbove.setSuffix(_translate("Settings", " px"))
        self.spnEditorParaBelow.setSuffix(_translate("Settings", " px"))
        self.groupBox_15.setTitle(_translate("Settings", "Cursor"))
        self.chkEditorCursorWidth.setText(_translate("Settings", "Use block insertion of"))
        self.spnEditorCursorWidth.setSuffix(_translate("Settings", " px"))
        self.chkEditorNoBlinking.setText(_translate("Settings", "Disable blinking"))
        self.chkEditorTypeWriterMode.setText(_translate("Settings", "Typewriter mode"))
        self.label_52.setText(_translate("Settings", "Focus mode"))
        self.cmbEditorFocusMode.setItemText(0, _translate("Settings", "None"))
        self.cmbEditorFocusMode.setItemText(1, _translate("Settings", "Sentence"))
        self.cmbEditorFocusMode.setItemText(2, _translate("Settings", "Line"))
        self.cmbEditorFocusMode.setItemText(3, _translate("Settings", "Paragraph"))
        self.tabViews.setTabText(self.tabViews.indexOf(self.tab_4), _translate("Settings", "Text editor"))
        self.lblTitleLabels.setText(_translate("Settings", "Labels"))
        self.btnLabelColor.setShortcut(_translate("Settings", "Ctrl+S"))
        self.lblTitleStatus.setText(_translate("Settings", "Status"))
        self.lblTitleFullscreen.setText(_translate("Settings", "Fullscreen"))
        self.btnThemeAdd.setText(_translate("Settings", "New"))
        self.btnThemeEdit.setText(_translate("Settings", "Edit"))
        self.btnThemeRemove.setText(_translate("Settings", "Delete"))
        self.label_33.setText(_translate("Settings", "Theme name:"))
        self.btnThemeEditOK.setText(_translate("Settings", "Apply"))
        self.btnThemeEditCancel.setText(_translate("Settings", "Cancel"))
        self.cmbThemeEdit.setItemText(0, _translate("Settings", "Window Background"))
        self.cmbThemeEdit.setItemText(1, _translate("Settings", "Text Background"))
        self.cmbThemeEdit.setItemText(2, _translate("Settings", "Text Options"))
        self.cmbThemeEdit.setItemText(3, _translate("Settings", "Paragraph Options"))
        self.label_17.setText(_translate("Settings", "Color:"))
        self.label_18.setText(_translate("Settings", "Image:"))
        self.label_19.setText(_translate("Settings", "Type:"))
        self.cmbThemBackgroundType.setItemText(0, _translate("Settings", "No Image"))
        self.cmbThemBackgroundType.setItemText(1, _translate("Settings", "Tiled"))
        self.cmbThemBackgroundType.setItemText(2, _translate("Settings", "Centered"))
        self.cmbThemBackgroundType.setItemText(3, _translate("Settings", "Stretched"))
        self.cmbThemBackgroundType.setItemText(4, _translate("Settings", "Scaled"))
        self.cmbThemBackgroundType.setItemText(5, _translate("Settings", "Zoomed"))
        self.label_20.setText(_translate("Settings", "Color:"))
        self.label_21.setText(_translate("Settings", "Opacity:"))
        self.spnThemeTextBackgroundOpacity.setSuffix(_translate("Settings", "%"))
        self.label_22.setText(_translate("Settings", "Position:"))
        self.cmbThemeTextPosition.setItemText(0, _translate("Settings", "Left"))
        self.cmbThemeTextPosition.setItemText(1, _translate("Settings", "Center"))
        self.cmbThemeTextPosition.setItemText(2, _translate("Settings", "Right"))
        self.cmbThemeTextPosition.setItemText(3, _translate("Settings", "Stretched"))
        self.label_23.setText(_translate("Settings", "Width:"))
        self.spnThemeTextWidth.setSuffix(_translate("Settings", " px"))
        self.spnThemeTextRadius.setSuffix(_translate("Settings", " px"))
        self.label_24.setText(_translate("Settings", "Corner radius:"))
        self.label_25.setText(_translate("Settings", "Margins:"))
        self.spnThemeTextMargins.setSuffix(_translate("Settings", " px"))
        self.label_34.setText(_translate("Settings", "Padding:"))
        self.spnThemeTextPadding.setSuffix(_translate("Settings", " px"))
        self.label_29.setText(_translate("Settings", "Color:"))
        self.label_30.setText(_translate("Settings", "Font:"))
        self.label_31.setText(_translate("Settings", "Size:"))
        self.label_32.setText(_translate("Settings", "Misspelled:"))
        self.label_26.setText(_translate("Settings", "Line spacing:"))
        self.cmbThemeLineSpacing.setItemText(0, _translate("Settings", "Single"))
        self.cmbThemeLineSpacing.setItemText(1, _translate("Settings", "1.5 lines"))
        self.cmbThemeLineSpacing.setItemText(2, _translate("Settings", "Double"))
        self.cmbThemeLineSpacing.setItemText(3, _translate("Settings", "Proportional"))
        self.spnThemeLineSpacing.setSuffix(_translate("Settings", "%"))
        self.label_27.setText(_translate("Settings", "Tab width:"))
        self.spnThemeTabWidth.setSuffix(_translate("Settings", " px"))
        self.label_28.setText(_translate("Settings", "Spacing:"))
        self.spnThemeParaAbove.setSuffix(_translate("Settings", " px"))
        self.spnThemeParaBelow.setSuffix(_translate("Settings", " px"))
        self.chkThemeIndent.setText(_translate("Settings", "Indent 1st line"))
        self.cmbThemeAlignment.setItemText(0, _translate("Settings", "Left"))
        self.cmbThemeAlignment.setItemText(1, _translate("Settings", "Center"))
        self.cmbThemeAlignment.setItemText(2, _translate("Settings", "Right"))
        self.cmbThemeAlignment.setItemText(3, _translate("Settings", "Justify"))
        self.label_53.setText(_translate("Settings", "Alignment"))



#!/usr/bin/env python
# --!-- coding: utf8 --!--
from PyQt5.QtCore import Qt
from PyQt5.QtGui import QCursor
from PyQt5.QtWidgets import QTreeView, QAction

from manuskript.enums import Outline
from manuskript.functions import mainWindow
from manuskript.ui.views.dndView import dndView
from manuskript.ui.views.outlineBasics import outlineBasics
from manuskript.ui.views.treeDelegates import treeTitleDelegate


class treeView(QTreeView, dndView, outlineBasics):
    def __init__(self, parent=None):
        QTreeView.__init__(self, parent)
        dndView.__init__(self, parent)
        outlineBasics.__init__(self, parent)
        self._indexesToOpen = None

    def setModel(self, model):
        QTreeView.setModel(self, model)

        # Hiding columns
        for c in range(self.model().columnCount()):
            self.hideColumn(c)

        self.showColumn(Outline.title)

        # Setting delegate
        self.titleDelegate = treeTitleDelegate()
        self.setItemDelegateForColumn(Outline.title, self.titleDelegate)

    def makePopupMenu(self):
        menu = outlineBasics.makePopupMenu(self)
        first = menu.actions()[3]

        # Open item in new tab
        #sel = self.selectedIndexes()
        pos = self.viewport().mapFromGlobal(QCursor.pos())
        mouseIndex = self.indexAt(pos)

        # Expand /collapse item
        if mouseIndex.isValid():
            # index = self.currentIndex()
            item = mouseIndex.internalPointer()
            if item.isFolder():
                self.actExpand = QAction(self.tr("Expand {}").format(item.title()), menu)
                self.actExpand.triggered.connect(self.expandCurrentIndex)
                menu.insertAction(first, self.actExpand)

                self.actCollapse = QAction(self.tr("Collapse {}").format(item.title()), menu)
                self.actCollapse.triggered.connect(self.collapseCurrentIndex)
                menu.insertAction(first, self.actCollapse)

                menu.insertSeparator(first)

        # Expand /collapse all
        self.actExpandAll = QAction(self.tr("Expand All"), menu)
        self.actExpandAll.triggered.connect(self.expandAll)
        menu.insertAction(first, self.actExpandAll)

        self.actCollapseAll = QAction(self.tr("Collapse All"), menu)
        self.actCollapseAll.triggered.connect(self.collapseAll)
        menu.insertAction(first, self.actCollapseAll)

        menu.insertSeparator(first)

        return menu

    def expandCurrentIndex(self, index=None):
        if index is None or type(index) == bool:
            index = self._indexesToOpen[0]  # self.currentIndex()

        self.expand(index)
        for i in range(self.model().rowCount(index)):
            idx = self.model().index(i, 0, index)
            self.expandCurrentIndex(index=idx)

    def collapseCurrentIndex(self, index=None):
        if index is None or type(index) == bool:
            index = self._indexesToOpen[0]  # self.currentIndex()

        self.collapse(index)
        for i in range(self.model().rowCount(index)):
            idx = self.model().index(i, 0, index)
            self.collapseCurrentIndex(index=idx)

    def dragMoveEvent(self, event):
        dndView.dragMoveEvent(self, event)
        QTreeView.dragMoveEvent(self, event)

    def mouseReleaseEvent(self, event):
        QTreeView.mouseReleaseEvent(self, event)
        outlineBasics.mouseReleaseEvent(self, event)
